Package: HDInterval
Type: Package
Title: Highest (Posterior) Density Intervals
Version: 0.2.4
Date: 2022-11-16
Suggests: coda
Authors@R: c(person("Ngumbang", "Juat", role="cre", email="ngumbangjuat@hotmail.com"),
  person("Mike", "Meredith", role="aut"),
  person("John", "Kruschke", role="aut"))
Description: A generic function and a set of methods to calculate highest density intervals for a variety of classes of objects which can specify a probability density distribution, including MCMC output, fitted density objects, and functions.
License: GPL-3
NeedsCompilation: no
Packaged: 2022-11-16 11:50:31 UTC; User
Author: Ngumbang Juat [cre],
  Mike Meredith [aut],
  John Kruschke [aut]
Maintainer: Ngumbang Juat <ngumbangjuat@hotmail.com>
Repository: CRAN
Date/Publication: 2022-11-17 18:10:21 UTC
Built: R 4.4.0; ; 2024-05-18 08:19:49 UTC; unix
