Package: HDInterval
Type: Package
Title: Highest (Posterior) Density Intervals
Version: 0.2.0
Date: 2018-06-09
Suggests: coda
Author: Mike Meredith and John Kruschke
Maintainer: Mike Meredith <mmeredith@wcs.org>
Description: A generic function and a set of methods to calculate highest density intervals for a variety of classes of objects which can specify a probability density distribution, including MCMC output, fitted density objects, and functions.
License: GPL-3
NeedsCompilation: no
Packaged: 2018-06-09 11:09:04 UTC; MIKE
Repository: CRAN
Date/Publication: 2018-06-09 15:46:43 UTC
Built: R 3.5.1; ; 2018-09-20 19:58:25 UTC; windows
